@@ -47,13 +47,19 @@ class PlusDataFrame():
             logging.info('Variable "unwanted_columns" is expected to be of type list or string')
             raise TypeError(f'"columns" variable is of type {type(self.unwanted_columns)}, should be of type list or string.')
 
-        #expecting a list or string in the environment variable
-        #columns = os.environ['plus_bi_columns_to_be_removed'].split(';')        
-        for col in self.unwanted_columns:
-            try:
-                self.df.drop(col, axis=1, inplace=True)
-            except Exception as e:
-                logging.info(f'Exception raised: {e}')    
+        try:
+            del self.df[None]  
+        except Exception as e:
+            logging.debug('No columns with name "None" found') 
+        lst_idx_to_del = []
+        for count, col in enumerate(self.df.columns):
+            if str(col) in self.unwanted_columns:
+                lst_idx_to_del.append(count)
+
+        for idx in reversed(lst_idx_to_del):
+            self.df.drop(self.df.columns[idx], axis=1, inplace=True)
+            #expecting a list or string in the environment variable
+            #columns = os.environ['plus_bi_columns_to_be_removed'].split(';')        
 
     @plus_helper.measure_runtime
     def remove_empty_records(self):
@@ -88,11 +94,11 @@ class PlusDataFrame():
         for expected_column, v in self.header_rename_dict.items():
             try:
                 if not expected_column in self.df.columns:                
-                    raise AssertionError(f"Did not find column: {expected_column}")
+                    logging.info(f"Did not find column: {expected_column}")
             except Exception as e:
                     logging.error(f'Exception raised: {e}')
 
-        logging.info('All columns present, renaming them.')
+        logging.info('Renaming present columns.')
         self.df.rename(columns=self.header_rename_dict, inplace=True)
 
     def add_default_values(self):
@@ -104,9 +110,10 @@ class PlusDataFrame():
         #expecting a dict in the environment variable with the following format:
         #var_dict = var_dict = {'Date' : 'datetime.date.today()', 'DateTime' : 'datetime.datetime.now()' , 'Integer' : '0', 'Float' : '0.0', 'String' : 'Something'}
         #!!NOTE: for date(time) use the functions used in the example.
-        try:            
+        try:    
+            logging.info(f'Adding default values to attributes.')        
             for attr, default_value in self.default_values_dict.items():
-                logging.info(f'Adding default value for attribute "{attr}".')
+                
                 try:
                     #first we check if the string can be evaluated as another Class 
                     try:
@@ -146,10 +153,12 @@ class PlusDataFrame():
 
             for key, val in self.datatypes_dict.items():   
                 if val == 'float':
-                    logging.info(f'Replacing commas with full stops in numbers for attribute: {key}')
-                    self.df[f'{key}_new'] = self.df[key].str.replace(',','.')
-                    self.df[key] = self.df[f'{key}_new'].fillna(self.df[key]).astype(dtype='float')
-                    del self.df[f'{key}_new']
+                    datatype_attr = self.df[key].dtype
+                    logging.info(f'Replacing commas with full stops in numbers for attribute: {key}, ')
+                    if 'float' not in str(datatype_attr):
+                        self.df[f'{key}_new'] = self.df[key].str.replace(',','.')
+                        self.df[key] = self.df[f'{key}_new'].fillna(self.df[key]).astype(dtype='float')
+                        del self.df[f'{key}_new']
                 elif val == 'bool':
                     numpy_array = self.df.loc[:, key]
                     numpy_array = numpy_array.replace({'J':True, 'Y':True, 'Yes':True, 'Ja':True, 'N':False, 'No':False, 'Nee':False})
