@@ -107,6 +107,9 @@ class PlusSubbatch():
         
     def send_batchfiles_report(self, destination_type, action):
         #destination_type valid entries: msg_queue, direct_sql
+
+        if not self.database:
+            self.database = self.batch.database
         if destination_type == 'msg_queue':
             pass
         elif destination_type == 'direct_sql':
@@ -147,7 +150,7 @@ SET [NumberOfRecords] = {self.number_of_records}
 ,[BatchEndDate] = {f'{self.database.null_value}' if self.state not in ('Done', 'Error', 'Processed') else f"'{plus_helper.getcurrent_datetime()}'"}
 WHERE SubBatchId = '{self.cds_subbatchid}'"""
                 self.database.execute_insert_query(sql)
-
+                
     def _get_onramp_msg_header(self):
         onramp_msg_header = {
                 "messageType": self.batch.business_object_type,
